package
module
Version:
v0.0.0-...-08ee9fb
Opens a new window with list of versions in this module.
Published: Mar 16, 2020
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Deserial(b []byte, obj interface{}) error
func Serial(obj interface{}) []byte
Serial will serialize all types of structs or pointer of structs in a binary format
Source Files
¶
Click to show internal directories.
Click to hide internal directories.